
% calculate the amplitude of the annual and
% semiannual signal in the COADS monthly climatology 
% SST and wind stress fields.
%
% The fitted signal is of the form
%   sst2=sstS(i,j,1)+ ...
%       cos(2*pi*t)*sstS(i,j,2)+cos(4*pi*t)*sstS(i,j,3)+ ...
%       sin(2*pi*t)*sstS(i,j,4)+sin(4*pi*t)*sstS(i,j,5);
%   where t is fractional year.
% More succinctly, for an N-by-1 vector t,
%   f=[1 2]; 
%   sst2=[ones(size(t)) cos(2*pi*t*f) sin(2*pi*t*f)]* ...
%       reshape(sstS(i,j,:),[5 1]);
%
% Code to plot the amplitude of the annual SST variation:
% sstA=sqrt(sstS(:,:,2).^2+sstS(:,:,4).^2);
% sstSA=sqrt(sstS(:,:,3).^2+sstS(:,:,5).^2);
% patchmap(lon_coads,lat_coads,sstA,[0 6]);

clear all;

[lon_coads,lat_coads,lonvec,latvec,sss,index, ...
    sst,netheat,eminusp,taux,tauy]=loadcoadsyear(-99);

t=(.5:11.5)'/12;   % time, fractional year
% allocate memory for mean, annual (cos, sin) and
%   semiannual (cos, sin)
sssS=NaN*ones(length(lonvec),5);
sstS=sssS; netheatS=sssS; eminuspS=sssS;
tauxS=sssS; tauyS=sssS;

y={'sss';'sst';'netheat';'eminusp';'taux';'tauy'};

for i=1:length(lonvec);
    fprintf('%d of %d\n',i,length(lonvec));
    
    y2=sss(:,i)+sst(:,i); q=find(isfinite(y2));
    if (length(q)>2)
        for j=1:length(y)
            eval(['y2=',char(y(j,:)),'(:,i);']);
            t2=[t;t+1;t+2;t+3;t+4;t+5;t+6;t+7;t+8;t+9];
            y2=[y2;y2;y2;y2;y2;y2;y2;y2;y2;y2];

            q=find(isfinite(y2));
            [y2,x,ex]=fitsine_getamp(t2(q),y2(q), ...
                [1 2],.1*std(y2(q)));
            eval([char(y(j,:)),'S(i,1)=x(5);']);
            eval([char(y(j,:)),'S(i,2)=x(1);']);
            eval([char(y(j,:)),'S(i,3)=x(2);']);
            eval([char(y(j,:)),'S(i,4)=x(3);']);
            eval([char(y(j,:)),'S(i,5)=x(4);']);
        end;
    end;
end;

lon=lon_coads; lat=lat_coads;

y2=NaN*ones(length(lat),length(lon));
for i=1:length(y);
    eval([char(y(i,:)),'S2=NaN*ones(', ...
            'length(lat),length(lon));']);
    for j=1:5;
        eval(['y2(index)=', ...
                char(y(i,:)),'S(:,', ...
                num2str(j),');']);
        eval([char(y(i,:)),'S2(:,:,j)=y2;']);
    end;
    eval([char(y(i,:)),'S=',char(y(i,:)),'S2;']);
    eval(['clear ',char(y(i,:)),'S2']);
end;

clear lon lat t t2 y y2 x ex q *A i j
clear sss sst taux tauy eminusp netheat latvec lonvec index

save coadsseas


