% comp2coads.m - create plots to compare the
% magnitude of fields in various climatologies
% to UWM/COADS

clear all;
clf;

for clim=1:4;
    
    if (clim==1) 
        loadclim='loadcoadsyear(-99);';
        linestyle='-k';
    elseif (clim==2)
        loadclim='loadsocyear(-99);';
        linestyle='-b';
    elseif (clim==3)
        loadclim='loadsocyear(-99,1);';
        linestyle='--b';
    else
        loadclim='loadncepyear(-99);';
        linestyle='-r';
    end;
    
    eval(['[lon,lat,lonvec,latvec,sss,index,' ...
         'sst,netheat,eminusp,taux,tauy]=', ...
         loadclim]);
 
    T=NaN*ones(length(lat),length(lon));
    H=T;P=T;W=T;
    T(index)=mean(sst,1);
    H(index)=mean(netheat,1);
    P(index)=-mean(eminusp,1)*3600*24*365.24;
    W(index)=sqrt(mean(taux,1).^2+mean(tauy,1).^2);
    
    subplot(141);
    plot(nanmean(T'),lat,linestyle);
    title('SST (^\circC)')
    hold on;
    
    subplot(142);
    plot(nanmean(H'),lat,linestyle);
    title('Q_{net} (W/m^2)')
    hold on;
    
    subplot(143);
    plot(nanmean(P'),lat,linestyle);
    title('P-E (m/year)')
    hold on;
    
    subplot(144);
    plot(nanmean(W'),lat,linestyle);
    title('wind stress (N/m^2)')
    hold on;
end;

for i=1:4;
    subplot(1,4,i);
    set(gca,'ylim',[-90 90]);
    plot([0 0],[-90 90],'color',[.5 .5 .5]);
    hold off;
end;
