
% ensocomposite - regenerate Giannini et al (2004), Fig. 3
%  March-May SST anomaly pattern for composite years:
%   warm ENSO, cold ENSO, and warm/cold with "concordant"
%   and "discordant" meridional gradient conditions.

clear all;

for ensembleloop=1:6;

    if (ensembleloop==1)
        yr=[1958 1966 1970 1973 1977 1983 1987 1988];   % ENSO warm
    elseif (ensembleloop==2)
        yr=[1956 1965 1968 1971 1974 1976 1985 1989];   % ENSO cold
    elseif (ensembleloop==3)
        yr=[1958 1966 1970];    % warm condordant
    elseif (ensembleloop==4)
        yr=[1965 1968 1971 1974 1985 1989];     % cold concordant
    elseif (ensembleloop==5)
        yr=[1973 1977 1983 1987 1988];  % warm discordant
    else
        yr=[1956 1976];  % cold discordant
    end;

[Lon,Lat,lonvec,latvec,sssB,index, ...
	    sstB,netheatB,eminuspB,tauxB,tauyB]=loadcoadsyear(-99);
sstB=sstB(3:5,:);
eminuspB=eminuspB(3:5,:);

ssta=NaN*ones(length(Lat),length(Lon));
SST=NaN*ones(length(Lat),length(Lon),length(yr));
EmP=SST;

for yind=1:length(yr);
    [lon_coads,lat_coads,lonvec,latvec,sss,index, ...
	    sst,netheat,eminusp,taux,tauy]=loadcoadsyear(yr(yind));
    sst=sst(3:5,:);
    sst=sst-sstB;
    ssta(index)=mean(sst,1);
    SST(:,:,yind)=ssta;
    
    eminusp=eminusp(3:5,:);
    eminusp=eminusp-eminuspB;
    ssta(index)=mean(eminusp,1);
    EmP(:,:,yind)=ssta;
end;

SSTmaster(:,:,ensembleloop)=nanmean2(SST,3);
EmPmaster(:,:,ensembleloop)=nanmean2(EmP,3);

end;    % loop over ensembleloop

clf;colormap default;
load colormaps
colormap(anomCmap);
iin=find(abs(Lat)<=35);
jin=find(Lon>=-100 & Lon<=40);
for i=1:size(SSTmaster,3);
    subplot(3,2,i);
    contourf(Lon(jin),Lat(iin),SSTmaster(iin,jin,i),-1.4:.2:1.4);
    shading flat;
    caxis([-1.4 1.4])
    mapaxis([-90 35 -30 30])
    coasts(3,1,'k');
end;
subplot(321);title('warm ENSO SST (MAM1)')
subplot(322);title('cold ENSO SST (MAM1)')
subplot(323);title('warm ENSO/positive gradient')
subplot(324);title('cold ENSO/negative gradient')
subplot(325);title('warm ENSO/negative gradient')
subplot(326);title('cold ENSO/positive gradient');colorbarvert;

