function [lon_coads,lat_coads,lonvec,latvec,sss,index, ...
	sst,netheat,eminusp,taux,tauy]=loadcoadsyear(year);

% function [lon_coads,lat_coads,lonvec,latvec,sss,index, ...
%        sst,netheat,eminusp,taux,tauy]=loadcoadsyear(year);
%
% load a year (=45 through 89) of monthly 
% observations from the COADS fields.  Output
% is mean + anomaly.  For the climatology alone,
% input a negative number for "year".

direc='/phod007/lumpkin/coads/';
socdirec='/phod007/lumpkin/soc/';
% directory where the binary data is stored
directory='/WSmounts/phodnet/share/lumpkin/DASILVA/';

if (year>1900)
  year=year-1900;
end;
if (year>0 & (year<45 | year>89))
  disp('UWM/COADS only contains values for 1945/1-1989/12.');
  return;
end;

eval(['load ',direc,'coads lon lat sss index']);

lon_coads=lon';lat_coads=lat';
eval(['latvec=getnc(''',directory,'netheat'',''lat'');']);
eval(['lonvec=getnc(''',directory,'netheat'',''lon'');']);

latvec=latvec';
lonvec=lonvec';
q=find(lonvec>180);
lonvec(q)=lonvec(q)-360;

disp('Loading UWM/COADS monthly means');
eval(['load ',direc,'coads sst netheat eminusp taux tauy']);
%disp('Replacing UWM/COADS mean winds with SOC mean winds');
%eval(['load ',socdirec,'socwinds;']);

if (year>0);	% include yearly anomalies

yearindex=year-44;



fprintf('Loading UWM/COADS monthly anomalies for 19%d\n',year);
disp('        SST')
data='sst';
callstr=['''',directory,data,''''];
callstr=[callstr,',''anom'',','[', ...
	num2str(yearindex), ...
	' -1 -1],[',num2str(yearindex), ...
	' -1 -1],[1 -1 -1],-1'];
eval([data,'_anom=getnc_s(',callstr,');']);
sst=sst+sst_anom;

% constrained net heat flux (W/m^2)
disp('        net heating');
data='netheat';
callstr=['''',directory,data,''''];
callstr=[callstr,',''anom'',','[', ...
        num2str(yearindex), ...
        ' -1 -1],[',num2str(yearindex), ...
        ' -1 -1],[1 -1 -1],-1'];
eval([data,'_anom=getnc_s(',callstr,');']);
eval([data,'_anom=getnc_s(',callstr,');']);
netheat=netheat+netheat_anom;

% E-P: mm/3 hours
disp('        E-P');
data='eminusp';
callstr=['''',directory,data,''''];
callstr=[callstr,',''anom'',','[', ...
        num2str(yearindex), ...
        ' -1 -1],[',num2str(yearindex), ...
        ' -1 -1],[1 -1 -1],-1'];
eval([data,'_anom=getnc_s(',callstr,');']);
eval([data,'_anom=getnc_s(',callstr,');']);
% convert to m/s
eminusp_anom=eminusp_anom*1e-3/3/3600;
eminusp=eminusp+eminusp_anom;

% tau_x: N/m^2
disp('        tau_x');
data='taux3';
callstr=['''',directory,data,''''];
callstr=[callstr,',''anom'',','[', ...
        num2str(yearindex), ...
        ' -1 -1],[',num2str(yearindex), ...
        ' -1 -1],[1 -1 -1],-1'];
eval([data,'_anom=getnc_s(',callstr,');']);
eval([data,'_anom=getnc_s(',callstr,');']);
taux=taux+taux3_anom;

% tau_y: N/m^2
disp('        tau_y');
data='tauy3';
callstr=['''',directory,data,''''];
callstr=[callstr,',''anom'',','[', ...
        num2str(yearindex), ...
        ' -1 -1],[',num2str(yearindex), ...
        ' -1 -1],[1 -1 -1],-1'];
eval([data,'_anom=getnc_s(',callstr,');']);
eval([data,'_anom=getnc_s(',callstr,');']);
tauy=tauy+tauy3_anom;

end;            % include yearly anomalies

% NaN-out values which contain ice temp in sst
% (allow a 1 psu increase in sss to account
% for possible monthly anomaly)
sstf=sw_fp(sss+1,zeros(size(sss)));
q=find(sst<sstf | isnan(sstf));
sst(q)=NaN;
eminusp(q)=NaN;
netheat(q)=NaN;
taux(q)=NaN;
tauy(q)=NaN;

