% make_coads_mean.m
%
% read the COADS Air-Sea climatological fields
% (time mean 1945-1989) and calculate
% the distribution of gamma, density, mass,
% heat and salt formation terms.

% load lat, lon and indices (see index2d.m)
load index2d

% directory where the binary data is stored
directory='/home/lasalle0/kspeer/climate/DASILVA/';

% load the COADS lat and lon vectors
eval(['latc=getnc(''',directory,'sst'',''lat'');']);
eval(['lonc=getnc(''',directory,'sst'',''lon'');']);
latc=latc';lonc=lonc';

disp('Reading SST')
data='sst';
eval([data,'=getnc(''',directory,data,''',''clm'');']);

disp('        SSS');
data='salinity';
eval([data,'=getnc(''',directory,data,''',''clm'');']);
sss=salinity;clear salinity;

% constrained net heat flux (W/m^2)
disp('        net heating');
data='netheat';
eval([data,'=getnc(''',directory,data,''',''clm'');']);
netheaterr=10;
fprintf('  Heating std. error: %3.2f W/m^2.\n',netheaterr);

% E-P: mm/3 hours
disp('        E-P');
data='eminusp';
eval([data,'=getnc(''',directory,data,''',''clm'');']);
% convert to m/s
eminusp=eminusp*1e-3/3/3600;
eminusperr=0;
fprintf('  E-P std. error: %3.2f m/s.\n',eminusperr);

% tau_x: N/m^2
disp('        tau_x');
data='taux3';
eval([data,'=getnc(''',directory,data,''',''clm'');']);
taux=taux3;clear taux3;

% tau_y: N/m^2
disp('        tau_y');
data='tauy3';
eval([data,'=getnc(''',directory,data,''',''clm'');']);
tauy=tauy3;clear tauy3;

% ice mask
disp('        ice mask');
data='icemask';
eval([data,'=getnc(''',directory,data,''',''clm'');']);

clear directory data;

% calculate gamma

if (0)
  ssg=NaN*ones(size(sst));
  for month=1:12;
    fprintf('MONTH: %d\n',month);

    sss2=NaN*ones(length(lat),length(lon));
    sst2=sss2;
    sss2(index)=sss(month,:);
    sst2(index)=sst(month,:);

    disp('Calculating gamma (to 168): ');
    ssg2=NaN*ones(size(sst2));
    for i=1:length(lat);
      if (find(isnan(sss2(i,:))==0))
        fprintf(' %d',i);
        latg=max([lat(i) -80]);
        latg=min([latg 64]);
        ssg2(i,:)=gamma_n(sss2(i,:),sst2(i,:),zeros(size(lon)), ...
	  lon,latg*ones(size(lon)) );
      end;
    end;
    fprintf('.\n');
    eval(['!rm glabel*']);
    q=find(ssg2<=-99);
    ssg2(q)=NaN;
    clear i latg q;
    patchmap(lon,lat,ssg2);
    caxis2(ssg2,5);
    colorbar;
    pause(.1);

    % assign monthly snapshot to ssg
    for i=1:length(ssg);
      ssg(month,i)=ssg2(rindex(1,i),rindex(2,i));
    end;
  end;
  q=find(icemask==1);
  ssg(q)=NaN;
  save coadsgamma index lat latc lon lonc ssg
  clear sss2 sst2 ssg2 month q icemask;
else
  load coadsgamma ssg
end;

% calculate alpha (thermal expansion coeff., deg. C^-1),
% beta (saline contraction coeff., psu^-1),
% and Cp (specific heat, J/ kg C).
alpha=NaN*ones(size(sss));
beta=alpha;
Cp=alpha;
disp('Calculating alpha and beta.');
alpha=sw_alpha(sss,sst,zeros(size(sst)));
beta=sw_beta(sss,sst,zeros(size(sst)));
disp('Calculating Cp.')
Cp=sw_cp(sss,sst,zeros(size(sst)));

% calculate density rho(0,S,0) (kg/m^3) 
rho=NaN*ones(size(sss));rhoS0=rho;
rho=sw_dens(sss,sst,zeros(size(sst)));
rhoS0=sw_dens(zeros(size(sst)),sst,zeros(size(sst)));

%%% calculate A/S fluxes

% salt anomaly flux [psu/1e3] m/s ,
% [] are units of salinity anomaly=(S-35)/1e3.
fs=NaN*ones(size(sss));fserr=fs;
fs=((sss-35)/1e3).*eminusp./(1-sss/1000);
fserr= abs( ((sss-35)/1e3).*eminusperr./(1-sss/1000));

% heat flux (deg.C m/s)
fh=NaN*ones(size(sss));fherr=fh;
fh=netheat./Cp./rho;
% std. error of heat flux
fherr=abs(netheaterr./Cp./rho);

% density fluxes (kg/m^2 s)
fm=NaN*ones(size(sss));fmS=fm;fmH=fm;fmerr=fm;
% fmH: thermal density flux
fmH=rho.*-alpha.*fh;
% fmS: haline density flux
fmS=rhoS0.*beta.*(eminusp.*sss./(1-sss/1000));
% fm: net density flux
fm=fmH+fmS;
% std. error of net density flux
fmerr= sqrt( ...
        (-alpha.*netheaterr./Cp).^2 + ...
        (rhoS0.*beta.*eminusperr.*sss./(1-sss/1000)).^2 ...
        );


ssd=rho;
clear alpha beta rho rhoS0 Cp;
save coads
