% makesfcgamma.m
%
% make a vector of gamma vs. lat, showing the winter-
% outcropping value of gamma at each latitude.

clear all;
[lon_coads,lat_coads,lonvec,latvec,sss,index, ...
        sst,netheat,eminusp,taux,tauy]=loadcoadsyear(-99);

disp('Discarding non-Atlantic values.');
load atlcoords;
q=~isinpoly(lonvec,latvec,x,y);
truncatecoads

sst2=NaN*ones(length(lat_coads),length(lon_coads));
sss2=sst2;
ssd=zeros(size(sst2));
sst_dmax=sst2;sss_dmax=sst2;
for i=1:12;
  ssd2=NaN*ones(length(lat_coads),length(lon_coads));
  sst2(index)=sst(i,:);
  sss2(index)=sss(i,:);
  q=find(isfinite(sst2+sss2));
  ssd2(q)=sw_dens(sss2(q),sst2(q),zeros(size(q)));
  q=find(ssd2>ssd);
  if (length(q))
    ssd(q)=ssd2(q);
    sst_dmax(q)=sst2(q);
    sss_dmax(q)=sss2(q);
  end;
end;
ssd(find(~ssd))=NaN;
alatmat=lat_coads*ones(1,length(lon_coads));
alonmat=ones(length(lat_coads),1)*lon_coads';
q=find(alonmat<0);alonmat(q)=alonmat(q)+360;
q=find(alatmat<-79.999);alatmat(q)=-79.999;
q=find(alatmat>63.999);alatmat(q)=63.999;

% calculate sea surface gamma (ssg) from
% sss, sst.  Do this for denser values
% (rho>1026), as lighter values can crash
% the gamma_n routine.  For these lighter
% values, exploit the nearly-linear relationship
% between rho and gamma at densities lighter
% than 1027.
ssg=NaN*ones(size(ssd));
q=find(ssd>1026 & alatmat<63.999);
disp('Calculating maximum surface values of gamma');
ssg(q)=gamma_n(sss_dmax(q),sst_dmax(q), ...
	zeros(size(q)),alonmat(q),alatmat(q));
q=find(ssg<0);ssg(q)=NaN;
% use linear relation for smaller values of ssd
q=find(isfinite(ssg) & ssd<1027);
[p,s]=polyfit(ssd(q),ssg(q),1);
q=find(isnan(ssg) & ssd<1027);
ssg(q)=polyval(p,ssd(q));
% use approximately linear relation for larger values
q=find(ssg>28.05 & ssd>1027.65);
[p,s]=polyfit(ssd(q),ssg(q),1);
q=find(isnan(ssg) & ssd>1027.65);
ssg(q)=polyval(p,ssd(q));
% fill remaining high-latitude NaNs in ssg
ssg=fillnans(ssg,0);
q=find(isnan(ssd));ssg(q)=NaN;

area=sw_area(lon_coads,lat_coads);
% convert ssg to layer number
glev;
gamma2(1)=-999;
gamma2(length(gamma2))=999;
sslay=NaN*ones(size(ssg));
q=find(isfinite(ssg));
for i=1:length(q);
  q2=find(gamma2<ssg(q(i)));
  if (length(q2))
    sslay(q(i))=max(q2);
  end;
end;

% calculate outcrop area as function
% of layer, in each latitude band,
% integrated from densest to
% lightest layer.  Find where cumulative
% area surpasses 100km^2, and define that
% layer as sslay_max.
threshold=(100e3)^2;
sslay_max=NaN*ones(size(lat_coads));
for i=1:length(lat_coads);
  larea=NaN*ones(size(glayers));
  for j=1:length(glayers);
    q=find(sslay(i,:)==j);
    if (length(q))
      larea(j)=sum(area(i,q));
    end;
  end;
  q=find(isnan(larea));
  larea(q)=0;
  larea=flipud(cumsum(flipud(larea)));
  q=find(larea>=threshold);
  if (length(q))
    sslay_max(i)=max(q);
  end;
end;

% smooth the profile
lay=sslay_max;
for i=3:length(sslay_max)-2;
  wts=[1 2 3 2 1]';
  lay(i)=nansum(lay(i-2:i+2).*wts)./sum(wts);
end;
sslay_max=lay;

plot(lat_coads,-sslay_max,'k');

save sfcgamma_atl lat_coads sslay_max;


